@@ -66,6 +66,22 @@ operation_parameter_map = {
             },
         ]
     },
+    '/accounts/{accountId}/orders/details-POST': {
+        'parameters': [
+            {
+                'name': 'brokerage_order_id'
+            },
+            {
+                'name': 'accountId'
+            },
+            {
+                'name': 'userId'
+            },
+            {
+                'name': 'userSecret'
+            },
+        ]
+    },
     '/accounts/{accountId}/orders-GET': {
         'parameters': [
             {
@@ -311,28 +327,6 @@ operation_parameter_map = {
             },
         ]
     },
-    '/accounts/{accountId}/optionStrategy-POST': {
-        'parameters': [
-            {
-                'name': 'underlying_symbol_id'
-            },
-            {
-                'name': 'legs'
-            },
-            {
-                'name': 'strategy_type'
-            },
-            {
-                'name': 'userId'
-            },
-            {
-                'name': 'userSecret'
-            },
-            {
-                'name': 'accountId'
-            },
-        ]
-    },
     '/accounts/{accountId}/optionsChain-GET': {
         'parameters': [
             {
@@ -349,22 +343,6 @@ operation_parameter_map = {
             },
         ]
     },
-    '/accounts/{accountId}/optionStrategy/{optionStrategyId}-GET': {
-        'parameters': [
-            {
-                'name': 'userId'
-            },
-            {
-                'name': 'userSecret'
-            },
-            {
-                'name': 'accountId'
-            },
-            {
-                'name': 'optionStrategyId'
-            },
-        ]
-    },
     '/accounts/{accountId}/options-GET': {
         'parameters': [
             {
@@ -378,31 +356,6 @@ operation_parameter_map = {
             },
         ]
     },
-    '/accounts/{accountId}/optionStrategy/{optionStrategyId}/execute-POST': {
-        'parameters': [
-            {
-                'name': 'order_type'
-            },
-            {
-                'name': 'time_in_force'
-            },
-            {
-                'name': 'userId'
-            },
-            {
-                'name': 'userSecret'
-            },
-            {
-                'name': 'accountId'
-            },
-            {
-                'name': 'optionStrategyId'
-            },
-            {
-                'name': 'price'
-            },
-        ]
-    },
     '/currencies/rates/{currencyPair}-GET': {
         'parameters': [
             {
@@ -443,10 +396,10 @@ operation_parameter_map = {
             },
         ]
     },
-    '/brokerages/{brokerageId}/instruments-GET': {
+    '/brokerages/{slug}/instruments-GET': {
         'parameters': [
             {
-                'name': 'brokerageId'
+                'name': 'slug'
             },
         ]
     },
@@ -480,6 +433,9 @@ operation_parameter_map = {
     },
     '/accounts/{accountId}/trading/cancel-POST': {
         'parameters': [
+            {
+                'name': 'brokerage_order_id'
+            },
             {
                 'name': 'userId'
             },
@@ -489,13 +445,13 @@ operation_parameter_map = {
             {
                 'name': 'accountId'
             },
-            {
-                'name': 'brokerage_order_id'
-            },
         ]
     },
     '/accounts/{accountId}/orders/cancel-POST': {
         'parameters': [
+            {
+                'name': 'brokerage_order_id'
+            },
             {
                 'name': 'userId'
             },
@@ -505,9 +461,6 @@ operation_parameter_map = {
             {
                 'name': 'accountId'
             },
-            {
-                'name': 'brokerage_order_id'
-            },
         ]
     },
     '/accounts/{accountId}/trading/instruments/cryptocurrencyPairs/{instrumentSymbol}/quote-GET': {
@@ -611,9 +564,6 @@ operation_parameter_map = {
             {
                 'name': 'userSecret'
             },
-            {
-                'name': 'symbol'
-            },
             {
                 'name': 'price'
             },
@@ -625,6 +575,46 @@ operation_parameter_map = {
             },
         ]
     },
+    '/accounts/{accountId}/trading/crypto-POST': {
+        'parameters': [
+            {
+                'name': 'instrument'
+            },
+            {
+                'name': 'side'
+            },
+            {
+                'name': 'type'
+            },
+            {
+                'name': 'time_in_force'
+            },
+            {
+                'name': 'amount'
+            },
+            {
+                'name': 'userId'
+            },
+            {
+                'name': 'userSecret'
+            },
+            {
+                'name': 'accountId'
+            },
+            {
+                'name': 'limit_price'
+            },
+            {
+                'name': 'stop_price'
+            },
+            {
+                'name': 'post_only'
+            },
+            {
+                'name': 'expiration_date'
+            },
+        ]
+    },
     '/trade/place-POST': {
         'parameters': [
             {
@@ -712,7 +702,7 @@ operation_parameter_map = {
             },
         ]
     },
-    '/accounts/{accountId}/trading/simple-POST': {
+    '/accounts/{accountId}/trading/crypto/preview-POST': {
         'parameters': [
             {
                 'name': 'instrument'
@@ -752,48 +742,11 @@ operation_parameter_map = {
             },
         ]
     },
-    '/accounts/{accountId}/trading/simple/preview-POST': {
+    '/accounts/{accountId}/trading/replace-POST': {
         'parameters': [
             {
-                'name': 'instrument'
+                'name': 'brokerage_order_id'
             },
-            {
-                'name': 'side'
-            },
-            {
-                'name': 'type'
-            },
-            {
-                'name': 'time_in_force'
-            },
-            {
-                'name': 'amount'
-            },
-            {
-                'name': 'userId'
-            },
-            {
-                'name': 'userSecret'
-            },
-            {
-                'name': 'accountId'
-            },
-            {
-                'name': 'limit_price'
-            },
-            {
-                'name': 'stop_price'
-            },
-            {
-                'name': 'post_only'
-            },
-            {
-                'name': 'expiration_date'
-            },
-        ]
-    },
-    '/accounts/{accountId}/trading/simple/{brokerageOrderId}/replace-PATCH': {
-        'parameters': [
             {
                 'name': 'action'
             },
@@ -806,9 +759,6 @@ operation_parameter_map = {
             {
                 'name': 'accountId'
             },
-            {
-                'name': 'brokerageOrderId'
-            },
             {
                 'name': 'userId'
             },
