@@ -238,7 +238,6 @@ class BaseApi(api_client.Api):
         account_id: typing.Optional[str] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
-        symbol: typing.Optional[str] = None,
         price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         units: typing.Optional[typing.Union[int, float]] = None,
@@ -251,8 +250,6 @@ class BaseApi(api_client.Api):
         _body = {}
         if action is not None:
             _body["action"] = action
-        if symbol is not None:
-            _body["symbol"] = symbol
         if instrument is not None:
             _body["instrument"] = instrument
         if order_type is not None:
@@ -558,7 +555,6 @@ class PlaceBracketOrder(BaseApi):
         account_id: typing.Optional[str] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
-        symbol: typing.Optional[str] = None,
         price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         units: typing.Optional[typing.Union[int, float]] = None,
@@ -583,7 +579,6 @@ class PlaceBracketOrder(BaseApi):
             account_id=account_id,
             user_id=user_id,
             user_secret=user_secret,
-            symbol=symbol,
             price=price,
             stop=stop,
             units=units,
@@ -607,7 +602,6 @@ class PlaceBracketOrder(BaseApi):
         account_id: typing.Optional[str] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
-        symbol: typing.Optional[str] = None,
         price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         units: typing.Optional[typing.Union[int, float]] = None,
@@ -631,7 +625,6 @@ class PlaceBracketOrder(BaseApi):
             account_id=account_id,
             user_id=user_id,
             user_secret=user_secret,
-            symbol=symbol,
             price=price,
             stop=stop,
             units=units,
@@ -657,7 +650,6 @@ class ApiForpost(BaseApi):
         account_id: typing.Optional[str] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
-        symbol: typing.Optional[str] = None,
         price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         units: typing.Optional[typing.Union[int, float]] = None,
@@ -682,7 +674,6 @@ class ApiForpost(BaseApi):
             account_id=account_id,
             user_id=user_id,
             user_secret=user_secret,
-            symbol=symbol,
             price=price,
             stop=stop,
             units=units,
@@ -706,7 +697,6 @@ class ApiForpost(BaseApi):
         account_id: typing.Optional[str] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
-        symbol: typing.Optional[str] = None,
         price: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         stop: typing.Optional[typing.Optional[typing.Union[int, float]]] = None,
         units: typing.Optional[typing.Union[int, float]] = None,
@@ -730,7 +720,6 @@ class ApiForpost(BaseApi):
             account_id=account_id,
             user_id=user_id,
             user_secret=user_secret,
-            symbol=symbol,
             price=price,
             stop=stop,
             units=units,
