@@ -32,17 +32,9 @@ import frozendict  # noqa: F401
 
 from snaptrade_client import schemas  # noqa: F401
 
-from snaptrade_client.model.brokerage import Brokerage as BrokerageSchema
-from snaptrade_client.model.brokerage_exchanges import BrokerageExchanges as BrokerageExchangesSchema
-from snaptrade_client.model.brokerage_type import BrokerageType as BrokerageTypeSchema
 from snaptrade_client.model.brokerage_authorization import BrokerageAuthorization as BrokerageAuthorizationSchema
-from snaptrade_client.model.brokerage_authorization_meta import BrokerageAuthorizationMeta as BrokerageAuthorizationMetaSchema
 
-from snaptrade_client.type.brokerage import Brokerage
-from snaptrade_client.type.brokerage_authorization_meta import BrokerageAuthorizationMeta
 from snaptrade_client.type.brokerage_authorization import BrokerageAuthorization
-from snaptrade_client.type.brokerage_type import BrokerageType
-from snaptrade_client.type.brokerage_exchanges import BrokerageExchanges
 
 from . import path
 
@@ -186,9 +178,10 @@ class BaseApi(api_client.Api):
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         stream: bool = False,
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         ApiResponseForDefaultAsync,
@@ -196,7 +189,7 @@ class BaseApi(api_client.Api):
         AsyncGeneratorResponse,
     ]:
         """
-        Get brokerage authorization details
+        Get connection detail
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -242,6 +235,7 @@ class BaseApi(api_client.Api):
             resource_path=used_path,
             method=method,
             configuration=self.api_client.configuration,
+            path_template='/authorizations/{authorizationId}',
             auth_settings=_auth,
             headers=_headers,
         )
@@ -253,6 +247,7 @@ class BaseApi(api_client.Api):
             auth_settings=_auth,
             prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
+            **kwargs
         )
     
         if stream:
@@ -319,7 +314,7 @@ class BaseApi(api_client.Api):
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         stream: bool = False,
     ) -> typing.Union[
@@ -328,7 +323,7 @@ class BaseApi(api_client.Api):
         api_client.ApiResponseWithoutDeserialization,
     ]:
         """
-        Get brokerage authorization details
+        Get connection detail
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -374,6 +369,7 @@ class BaseApi(api_client.Api):
             resource_path=used_path,
             method=method,
             configuration=self.api_client.configuration,
+            path_template='/authorizations/{authorizationId}',
             auth_settings=_auth,
             headers=_headers,
         )
@@ -426,6 +422,7 @@ class DetailBrokerageAuthorization(BaseApi):
         user_secret: typing.Optional[str] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         ApiResponseForDefaultAsync,
@@ -442,6 +439,7 @@ class DetailBrokerageAuthorization(BaseApi):
         return await self._adetail_brokerage_authorization_oapg(
             query_params=args.query,
             path_params=args.path,
+            **kwargs,
         )
     
     def detail_brokerage_authorization(
@@ -456,6 +454,7 @@ class DetailBrokerageAuthorization(BaseApi):
         ApiResponseForDefault,
         api_client.ApiResponseWithoutDeserialization,
     ]:
+        """ Returns a single connection for the specified ID. """
         args = self._detail_brokerage_authorization_mapped_args(
             query_params=query_params,
             path_params=path_params,
@@ -478,6 +477,7 @@ class ApiForget(BaseApi):
         user_secret: typing.Optional[str] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         ApiResponseForDefaultAsync,
@@ -494,6 +494,7 @@ class ApiForget(BaseApi):
         return await self._adetail_brokerage_authorization_oapg(
             query_params=args.query,
             path_params=args.path,
+            **kwargs,
         )
     
     def get(
@@ -508,6 +509,7 @@ class ApiForget(BaseApi):
         ApiResponseForDefault,
         api_client.ApiResponseWithoutDeserialization,
     ]:
+        """ Returns a single connection for the specified ID. """
         args = self._detail_brokerage_authorization_mapped_args(
             query_params=query_params,
             path_params=path_params,
