@@ -124,9 +124,10 @@ class BaseApi(api_client.Api):
     async def _aget_security_types_oapg(
         self,
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         stream: bool = False,
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         ApiResponseForDefaultAsync,
@@ -134,7 +135,7 @@ class BaseApi(api_client.Api):
         AsyncGeneratorResponse,
     ]:
         """
-        List of all security types
+        List security types
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -151,6 +152,7 @@ class BaseApi(api_client.Api):
             resource_path=used_path,
             method=method,
             configuration=self.api_client.configuration,
+            path_template='/securityTypes',
             auth_settings=_auth,
             headers=_headers,
         )
@@ -161,6 +163,7 @@ class BaseApi(api_client.Api):
             headers=_headers,
             auth_settings=_auth,
             timeout=timeout,
+            **kwargs
         )
     
         if stream:
@@ -225,7 +228,7 @@ class BaseApi(api_client.Api):
     def _get_security_types_oapg(
         self,
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         stream: bool = False,
     ) -> typing.Union[
@@ -234,7 +237,7 @@ class BaseApi(api_client.Api):
         api_client.ApiResponseWithoutDeserialization,
     ]:
         """
-        List of all security types
+        List security types
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -251,6 +254,7 @@ class BaseApi(api_client.Api):
             resource_path=used_path,
             method=method,
             configuration=self.api_client.configuration,
+            path_template='/securityTypes',
             auth_settings=_auth,
             headers=_headers,
         )
@@ -297,6 +301,7 @@ class GetSecurityTypes(BaseApi):
 
     async def aget_security_types(
         self,
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         ApiResponseForDefaultAsync,
@@ -306,6 +311,7 @@ class GetSecurityTypes(BaseApi):
         args = self._get_security_types_mapped_args(
         )
         return await self._aget_security_types_oapg(
+            **kwargs,
         )
     
     def get_security_types(
@@ -315,6 +321,7 @@ class GetSecurityTypes(BaseApi):
         ApiResponseForDefault,
         api_client.ApiResponseWithoutDeserialization,
     ]:
+        """ Return all available security types supported by SnapTrade. """
         args = self._get_security_types_mapped_args(
         )
         return self._get_security_types_oapg(
@@ -325,6 +332,7 @@ class ApiForget(BaseApi):
 
     async def aget(
         self,
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         ApiResponseForDefaultAsync,
@@ -334,6 +342,7 @@ class ApiForget(BaseApi):
         args = self._get_security_types_mapped_args(
         )
         return await self._aget_security_types_oapg(
+            **kwargs,
         )
     
     def get(
@@ -343,6 +352,7 @@ class ApiForget(BaseApi):
         ApiResponseForDefault,
         api_client.ApiResponseWithoutDeserialization,
     ]:
+        """ Return all available security types supported by SnapTrade. """
         args = self._get_security_types_mapped_args(
         )
         return self._get_security_types_oapg(
