@@ -18,25 +18,27 @@ from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 from snaptrade_client.type.underlying_symbol import UnderlyingSymbol
 
 class RequiredOptionsSymbol(TypedDict):
+    # Unique identifier for the option symbol within SnapTrade. This is the ID used to reference the symbol in SnapTrade API calls.
     id: str
 
+    # The [OCC symbol](https://en.wikipedia.org/wiki/Option_symbol) for the option.
     ticker: str
 
+    # The type of option. Either \"CALL\" or \"PUT\".
     option_type: str
 
+    # The option strike price.
     strike_price: typing.Union[int, float]
 
-    expiration_date: str
+    # The option expiration date.
+    expiration_date: date
 
     underlying_symbol: UnderlyingSymbol
 
 
 class OptionalOptionsSymbol(TypedDict, total=False):
+    # Whether the option is a mini option. Mini options have 10 underlying shares per contract instead of the standard 100.
     is_mini_option: bool
 
-    local_id: str
-
-    exchange_id: str
-
 class OptionsSymbol(RequiredOptionsSymbol, OptionalOptionsSymbol):
     pass
